import { Selected } from "@/Constants";
import { LanguagesData } from "@/Data/Layout/RightHeader";
import { useAppSelector } from "@/ReduxToolkit/Hooks";
import { setLanguage } from "@/ReduxToolkit/Reducers/LanguageSlice";
import { ChangeLngType } from "@/Types/Layout";
import { useTranslation } from "@/app/i18n/client";
import { usePathname, useRouter } from "next/navigation";
import { useEffect, useState } from "react";
import { useDispatch } from "react-redux";

const Languages = () => {
  const { i18LangStatus } = useAppSelector((state) => state.langSlice);
  const { i18n } = useTranslation(i18LangStatus);
  const [langDropdown, setLangDropdown] = useState(false);
  const pathname = usePathname();
  const router = useRouter();
  const dispatch = useDispatch();
  const currentLang = pathname.split('/')[1]
  const changeLng = (item: ChangeLngType) => {
    dispatch(setLanguage(item.data));
    i18n.changeLanguage(item.language);
    const languageCodeRegex = /^\/[a-z]{2}(\/|$)/;
    const updatedPath = pathname.replace(languageCodeRegex, `/${item.data}$1`);
    router.push(updatedPath);
    setLangDropdown(false)
  };

  const languageSelection = () => {
    setLangDropdown(!langDropdown);
  };
  useEffect(() => {
    const pathSegments = pathname.split("/").filter(Boolean);
    if (pathSegments.length > 0) {
      const language = pathSegments[0];
      if (language !== i18LangStatus) {
        dispatch(setLanguage(language));
      }
    }
  }, []);

  return (

      <ul className="footer-language simple-list">
        <li className="language-nav">
          <div className={`translate_wrapper ${langDropdown ? "active" : ""}`}>
            <div className="current_lang" onClick={languageSelection}>
              <span className="lang-txt f-light f-w-500">{currentLang}</span>
              <span className="ms-2">
                {" "}
                <i className="fa fa-caret-down txt-primary"></i>
              </span>
            </div>
            <div className={`more_lang ${langDropdown ? "active" : ""}`}>
              {LanguagesData.map((item, index) => (
                <div className="lang" data-value={item.language} key={index} onClick={() => changeLng(item)}>
                  <span className="lang-txt">
                    {item.language}
                    <span> ({item.data})</span>
                  </span>
                </div>
              ))}
            </div>
          </div>
        </li>
      </ul>
  
  );
};

export default Languages;
